@@ -14,7 +14,7 @@
  * License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, see <http://www.gnu.org/licenses/>. 
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -26,7 +26,7 @@
 #include <string.h>
 #include <assert.h>
 
-#include "gpa.h"   
+#include "gpa.h"
 #include "gtktools.h"
 #include "convert.h"
 #include "gpa-key-details.h"
@@ -59,11 +59,11 @@ enum
     ENTRY_SIG_FORCE_PIN,
 
     ENTRY_LAST
-  }; 
+  };
 
 
 /* Object's class definition.  */
-struct _GpaCMOpenpgpClass 
+struct _GpaCMOpenpgpClass
 {
   GpaCMObjectClass parent_class;
 };
@@ -105,7 +105,7 @@ struct _GpaCMOpenpgp
 
   /* True is this is a version 2 card. */
   int is_v2;
-  
+
   /* This flag is set while we are reloading data.  */
   int  reloading;
 };
@@ -118,7 +118,7 @@ static void gpa_cm_openpgp_finalize (GObject *object);
 
 
 
-/************************************************************ 
+/************************************************************
  *******************   Implementation   *********************
  ************************************************************/
 
@@ -132,12 +132,20 @@ get_manufacturer (unsigned int no)
     case 0x0001: return "PPC Card Systems";
     case 0x0002: return "Prism";
     case 0x0003: return "OpenFortress";
-    case 0x0004: return "Wewid AB";
+    case 0x0004: return "Wewid";
     case 0x0005: return "ZeitControl";
+    case 0x0006: return "Yubico";
+    case 0x0007: return "OpenKMS";
+    case 0x0008: return "LogoEmail";
 
     case 0x002A: return "Magrathea";
-      /* 0x00000 and 0xFFFF are defined as test cards per spec,
-         0xFFF00 to 0xFFFE are assigned for use with randomly created
+
+    case 0x1337: return "Warsaw Hackerspace";
+
+    case 0xF517: return "FSIJ";
+
+      /* 0x0000 and 0xFFFF are defined as test cards per spec,
+         0xFF00 to 0xFFFE are assigned for use with randomly created
          serial numbers.  */
     case 0x0000:
     case 0xffff: return "test card";
@@ -180,8 +188,8 @@ show_admin_pin_notice (GpaCMOpenpgp *card)
   /* FIXME:  How do we figure out our GtkWindow?  */
   dialog = gtk_message_dialog_new_with_markup (NULL /*GTK_WINDOW (card)*/,
                                                GTK_DIALOG_DESTROY_WITH_PARENT,
-                                               GTK_MESSAGE_INFO, 
-                                               GTK_BUTTONS_OK_CANCEL, 
+                                               GTK_MESSAGE_INFO,
+                                               GTK_BUTTONS_OK_CANCEL,
                                                NULL);
   gtk_message_dialog_set_markup (GTK_MESSAGE_DIALOG (dialog), string);
   okay = (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_OK);
@@ -319,13 +327,13 @@ update_entry_name (GpaCMOpenpgp *card, int entry_id, const char *string)
 static void
 update_entry_sex (GpaCMOpenpgp *card, int entry_id, const char *string)
 {
-  int idx;  
+  int idx;
 
   if (*string == '1')
-    idx = 0;  /* 'm' */ 
+    idx = 0;  /* 'm' */
   else if (*string == '2')
     idx = 1;  /* 'f' */
-  else 
+  else
     idx = 2;  /* 'u' is the default.  */
 
   gtk_combo_box_set_active (GTK_COMBO_BOX (card->entries[entry_id]), idx);
@@ -336,7 +344,7 @@ static void
 set_integer (GtkWidget *entry, int value)
 {
   char numbuf[35];
-  
+
   snprintf (numbuf, sizeof numbuf, "%d", value);
   gtk_label_set_text (GTK_LABEL (entry), numbuf);
 }
@@ -378,7 +386,7 @@ update_entry_chv_status (GpaCMOpenpgp *card, int entry_id, const char *string)
         string++;
     }
 
-  gtk_toggle_button_set_active 
+  gtk_toggle_button_set_active
     (GTK_TOGGLE_BUTTON (card->entries[ENTRY_SIG_FORCE_PIN]), !!force_pw1);
   set_integer (card->entries[ENTRY_PIN_RETRYCOUNTER], pw_retry[0]);
   set_integer (card->entries[ENTRY_PUK_RETRYCOUNTER], pw_retry[1]);
@@ -389,7 +397,7 @@ update_entry_chv_status (GpaCMOpenpgp *card, int entry_id, const char *string)
   /* Set the Change button label to reset or change depending on the
      current retry count.  Make the button insensitive if the
      Admin PIN is blocked.  */
-  gtk_button_set_label (GTK_BUTTON (card->change_pin_btn[0]), 
+  gtk_button_set_label (GTK_BUTTON (card->change_pin_btn[0]),
                         (!pw_retry[0] || (!pw_retry[1] && !card->is_v2)
                          ? _("Reset PIN") : _("Change PIN")));
   gtk_widget_set_sensitive (card->change_pin_btn[0], !!pw_retry[2]);
@@ -400,7 +408,7 @@ update_entry_chv_status (GpaCMOpenpgp *card, int entry_id, const char *string)
      button is required.  */
   if (card->is_v2)
     {
-      gtk_button_set_label (GTK_BUTTON (card->change_pin_btn[1]), 
+      gtk_button_set_label (GTK_BUTTON (card->change_pin_btn[1]),
                             (pw_retry[1]? _("Change PUK"):_("Reset PUK")));
       gtk_widget_set_sensitive (card->change_pin_btn[1], !!pw_retry[2]);
       gtk_widget_show_all (card->change_pin_btn[1]);
@@ -408,7 +416,7 @@ update_entry_chv_status (GpaCMOpenpgp *card, int entry_id, const char *string)
   else
     gtk_widget_hide_all (card->change_pin_btn[1]);
   gtk_widget_set_no_show_all (card->change_pin_btn[1], !card->is_v2);
-   
+
   /* The Admin PIN has always the same label.  If the Admin PIN is
      blocked the button is made insensitive.  Fixme: In the case of a
      blocked Admin PIN we should have a button to allow a factory
@@ -468,11 +476,11 @@ update_entry_key_attr (GpaCMOpenpgp *card, int entry_id, const char *string)
         items = DIM (card->key_attr); /* Attributes are mixed.  */
       else
         items = 1; /* All the same attributes.  */
-          
+
       buf = NULL;
       for (keyno=0; keyno < items; keyno++)
         {
-          tmpbuf = g_strdup_printf ("%s%s%s-%d", 
+          tmpbuf = g_strdup_printf ("%s%s%s-%d",
                                     buf? buf : "",
                                     buf? ", ":"",
                                     card->key_attr[keyno].algo ==  1?"RSA":
@@ -526,7 +534,9 @@ scd_getattr_cb (void *opaque, const char *status, const char *args)
           else if (*args == '3')
             entry_id = ENTRY_KEY_AUTH;
           else
-            ; /* Ooops.  */
+            {
+              /* Ooops.  */
+            }
           if (*args)
             {
               for (args++; spacep (args); args++)
@@ -542,10 +552,10 @@ scd_getattr_cb (void *opaque, const char *status, const char *args)
           if (parm->updfnc)
             parm->updfnc (parm->card, entry_id, tmp);
           else if (GTK_IS_LABEL (parm->card->entries[entry_id]))
-            gtk_label_set_text 
+            gtk_label_set_text
               (GTK_LABEL (parm->card->entries[entry_id]), tmp);
           else
-            gtk_entry_set_text 
+            gtk_entry_set_text
               (GTK_ENTRY (parm->card->entries[entry_id]), tmp);
           xfree (tmp);
         }
@@ -560,7 +570,7 @@ scd_getattr_cb (void *opaque, const char *status, const char *args)
     }
 
   return 0;
-}     
+}
 
 
 
@@ -587,7 +597,7 @@ reload_data (GpaCMOpenpgp *card)
     { NULL }
   };
   int attridx;
-  gpg_error_t err;
+  gpg_error_t err, operr;
   char command[100];
   struct scd_getattr_parm parm;
   gpgme_ctx_t gpgagent;
@@ -606,13 +616,13 @@ reload_data (GpaCMOpenpgp *card)
       parm.updfnc   = attrtbl[attridx].updfnc;
       snprintf (command, sizeof command, "SCD GETATTR %s", parm.name);
 
-      err = gpgme_op_assuan_transact (gpgagent,
-                                      command,
-                                      NULL, NULL,
-                                      NULL, NULL,
-                                      scd_getattr_cb, &parm);
+      err = gpgme_op_assuan_transact_ext (gpgagent,
+                                          command,
+                                          NULL, NULL,
+                                          NULL, NULL,
+                                          scd_getattr_cb, &parm, &operr);
       if (!err)
-        err = gpgme_op_assuan_result (gpgagent)->err;
+        err = operr;
 
       if (err)
         {
@@ -620,7 +630,7 @@ reload_data (GpaCMOpenpgp *card)
             ; /* Lost the card.  */
           else
             {
-              g_debug ("assuan command `%s' failed: %s <%s>\n", 
+              g_debug ("assuan command `%s' failed: %s <%s>\n",
                        command, gpg_strerror (err), gpg_strsource (err));
             }
           clear_card_data (card);
@@ -635,10 +645,10 @@ reload_data (GpaCMOpenpgp *card)
 
 
 static gpg_error_t
-save_attr (GpaCMOpenpgp *card, const char *name, 
+save_attr (GpaCMOpenpgp *card, const char *name,
            const char *value, int is_escaped)
 {
-  gpg_error_t err;
+  gpg_error_t err, operr;
   char *command;
   gpgme_ctx_t gpgagent;
 
@@ -660,18 +670,18 @@ save_attr (GpaCMOpenpgp *card, const char *name,
       command = g_strdup_printf ("SCD SETATTR %s %s", name, p);
       xfree (p);
     }
-  err = gpgme_op_assuan_transact (gpgagent,
-                                  command,
-                                  NULL, NULL,
-                                  NULL, NULL,
-                                  NULL, NULL);
+  err = gpgme_op_assuan_transact_ext (gpgagent,
+                                      command,
+                                      NULL, NULL,
+                                      NULL, NULL,
+                                      NULL, NULL, &operr);
   if (!err)
-    err = gpgme_op_assuan_result (gpgagent)->err;
+    err = operr;
 
   if (err && !(gpg_err_code (err) == GPG_ERR_CANCELED
                && gpg_err_source (err) == GPG_ERR_SOURCE_PINENTRY))
     {
-      char *message = g_strdup_printf 
+      char *message = g_strdup_printf
         (_("Error saving the changed values.\n"
            "(%s <%s>)"), gpg_strerror (err), gpg_strsource (err));
       gpa_cm_object_alert_dialog (GPA_CM_OBJECT (card), message);
@@ -684,7 +694,7 @@ save_attr (GpaCMOpenpgp *card, const char *name,
 
 /* Check the constraints for NAME and return a string with an error
    description or NULL if the name is fine.  */
-static const char * 
+static const char *
 check_one_name (const char *name)
 {
   int i;
@@ -699,7 +709,7 @@ check_one_name (const char *name)
   else if (strchr (name, '<'))
     return _("The \"<\" character may not be used.");
   else if (strstr (name, "  "))
-    return _("Double spaces are not allowed.");    
+    return _("Double spaces are not allowed.");
   else
     return NULL;
 }
@@ -713,8 +723,8 @@ save_entry_name (GpaCMOpenpgp *card)
   const char *errstr;
   int failed = ENTRY_FIRST_NAME;
 
-  first = gtk_entry_get_text (GTK_ENTRY (card->entries[ENTRY_FIRST_NAME])); 
-  last = gtk_entry_get_text (GTK_ENTRY (card->entries[ENTRY_LAST_NAME])); 
+  first = gtk_entry_get_text (GTK_ENTRY (card->entries[ENTRY_FIRST_NAME]));
+  last = gtk_entry_get_text (GTK_ENTRY (card->entries[ENTRY_LAST_NAME]));
   errstr = check_one_name (first);
   if (!errstr)
     {
@@ -725,7 +735,7 @@ save_entry_name (GpaCMOpenpgp *card)
   if (!errstr)
     {
       char *buffer, *p;
-      
+
       buffer = g_strdup_printf ("%s<<%s", last, first);
       for (p=buffer; *p; p++)
         if (*p == ' ')
@@ -755,7 +765,7 @@ save_entry_language (GpaCMOpenpgp *card)
   const char *errstr = NULL;
   const char *value, *s;
 
-  value = gtk_entry_get_text (GTK_ENTRY (card->entries[ENTRY_LANGUAGE])); 
+  value = gtk_entry_get_text (GTK_ENTRY (card->entries[ENTRY_LANGUAGE]));
   if (strlen (value) > 8 || (strlen (value) & 1))
     {
       errstr = _("Invalid length of the language preference.");
@@ -815,7 +825,7 @@ save_entry_pubkey_url (GpaCMOpenpgp *card)
   const char *errstr = NULL;
   const char *value;
 
-  value = gtk_entry_get_text (GTK_ENTRY (card->entries[ENTRY_PUBKEY_URL])); 
+  value = gtk_entry_get_text (GTK_ENTRY (card->entries[ENTRY_PUBKEY_URL]));
   if (strlen (value) > 254)
     {
       errstr = _("The field may not be longer than 254 characters.");
@@ -840,7 +850,7 @@ save_entry_login (GpaCMOpenpgp *card)
   const char *errstr = NULL;
   const char *value;
 
-  value = gtk_entry_get_text (GTK_ENTRY (card->entries[ENTRY_LOGIN])); 
+  value = gtk_entry_get_text (GTK_ENTRY (card->entries[ENTRY_LOGIN]));
   if (strlen (value) > 254)
     {
       errstr = _("The field may not be longer than 254 characters.");
@@ -865,7 +875,7 @@ save_entry_sig_force_pin (GpaCMOpenpgp *card)
   int value;
   const char *errstr = NULL;
 
-  value = gtk_toggle_button_get_active 
+  value = gtk_toggle_button_get_active
     (GTK_TOGGLE_BUTTON (card->entries[ENTRY_SIG_FORCE_PIN]));
 
   if (save_attr (card, "CHV-STATUS-1", value? "%00":"%01", 1))
@@ -894,7 +904,7 @@ edit_changed_cb (GtkEditable *editable, void *opaque)
       break;
   if (!(idx < ENTRY_LAST))
     return;
-  
+
   if (!card->changed[idx])
     {
       card->changed[idx] = TRUE;
@@ -918,7 +928,7 @@ edit_changed_combo_box_cb (GtkComboBox *cbox, void *opaque)
       break;
   if (!(idx < ENTRY_LAST))
     return;
-  
+
   if (!card->changed[idx])
     {
       int result;
@@ -930,7 +940,7 @@ edit_changed_combo_box_cb (GtkComboBox *cbox, void *opaque)
           result = save_entry_sex (card);
           /* Fixme: How should we handle errors? Trying it this way:
                  Always clear the changed flag, so that we will receive one
-                  again and grab the focus on error. 
+                  again and grab the focus on error.
              fails.  We may need to make use of the keynav-changed signal. */
           card->changed[idx] = 0;
           if (!result)
@@ -956,7 +966,7 @@ edit_toggled_cb (GtkToggleButton *toggle, void *opaque)
       break;
   if (!(idx < ENTRY_LAST))
     return;
-  
+
   if (!card->changed[idx])
     {
       card->changed[idx] = TRUE;
@@ -978,7 +988,7 @@ edit_focus_cb (GtkWidget *widget, GtkDirectionType direction, void *opaque)
   GpaCMOpenpgp *card = opaque;
   int idx;
   int result = FALSE; /* Continue calling other handlers.  */
-  
+
   for (idx=0; idx < ENTRY_LAST; idx++)
     if (card->entries[idx] == widget)
       break;
@@ -1030,7 +1040,7 @@ edit_focus_cb (GtkWidget *widget, GtkDirectionType direction, void *opaque)
       /* Entry IDX is about to receive the focus.  */
 /*       g_debug ("entry %d is about to receive the focus", idx); */
       show_edit_error (card, NULL);
-    } 
+    }
   return result;
 }
 
@@ -1040,7 +1050,7 @@ edit_focus_cb (GtkWidget *widget, GtkDirectionType direction, void *opaque)
 static void
 change_pin (GpaCMOpenpgp *card, int pinno)
 {
-  gpg_error_t err;
+  gpg_error_t err, operr;
   GtkWidget *dialog;
   gpgme_ctx_t gpgagent;
   int reset_mode = 0;
@@ -1119,9 +1129,9 @@ change_pin (GpaCMOpenpgp *card, int pinno)
                "A fresh standard card has set the Admin-PIN to the value "
                "<i>12345678</i>.  However, the issuer of your card might "
                "have initialized the card with a different Admin-PIN and "
-               "that Admin-PIN might only be nown to the issuer.  "
+               "that Admin-PIN might only be known to the issuer.  "
                "Please check the instructions of your issuer.\n"
-               "\n" 
+               "\n"
                "If you proceed you will be asked to enter the current "
                "value of the <b>Admin-PIN</b> and then to enter a new "
                "value for the PIN or the Reset Code and repeat that new "
@@ -1145,13 +1155,13 @@ change_pin (GpaCMOpenpgp *card, int pinno)
                "value at another prompt.");
   else
     string = "oops";
-            
-              
+
+
   /* FIXME:  How do we figure out our GtkWindow?  */
   dialog = gtk_message_dialog_new_with_markup (NULL /*GTK_WINDOW (card)*/,
                                                GTK_DIALOG_DESTROY_WITH_PARENT,
-                                               GTK_MESSAGE_INFO, 
-                                               GTK_BUTTONS_OK_CANCEL, 
+                                               GTK_MESSAGE_INFO,
+                                               GTK_BUTTONS_OK_CANCEL,
                                                NULL);
   gtk_message_dialog_set_markup (GTK_MESSAGE_DIALOG (dialog), string);
   okay = (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_OK);
@@ -1161,15 +1171,17 @@ change_pin (GpaCMOpenpgp *card, int pinno)
 
       snprintf (command, sizeof command, "SCD PASSWD%s %d",
                 reset_mode? " --reset":"", pinno+1);
-      err = gpgme_op_assuan_transact (gpgagent, command,
-                                      NULL, NULL, NULL, NULL, NULL, NULL);
-      if (!err) 
-        err = gpgme_op_assuan_result (gpgagent)->err;
+      err = gpgme_op_assuan_transact_ext (gpgagent, command,
+                                          NULL, NULL, NULL, NULL, NULL, NULL,
+                                          &operr);
+      if (!err)
+        err = operr;
+
       if (gpg_err_code (err) == GPG_ERR_CANCELED)
         okay = 0; /* No need to reload the data.  */
-      else if (err) 
+      else if (err)
         {
-          char *message = g_strdup_printf 
+          char *message = g_strdup_printf
             (_("Error changing or resetting the PIN/PUK.\n"
                "(%s <%s>)"), gpg_strerror (err), gpg_strsource (err));
           gpa_window_error (message, NULL);
@@ -1189,7 +1201,7 @@ change_pin_clicked_cb (void *widget, void *user_data)
 {
   GpaCMOpenpgp *card = user_data;
   int idx;
-  
+
   for (idx=0; idx < 3; idx++)
     if (widget == card->change_pin_btn[idx])
       {
@@ -1222,7 +1234,7 @@ entry_fpr_expanded_cb (GObject *object, GParamSpec *dummy, void *user_data)
     {
       const char *fpr, *src;
       char *rawfpr, *dst;
- 
+
       if (!card->key_details[keyidx])
         {
           card->key_details[keyidx] = gpa_key_details_new ();
@@ -1267,10 +1279,10 @@ pubkey_url_menu_fetch_key (GtkMenuItem *menuitem, void *opaque)
   gpg_error_t err;
   gpgme_data_t urllist;
   gpgme_ctx_t ctx;
-  
+
   (void)menuitem;
 
-  url = gtk_entry_get_text (GTK_ENTRY (card->entries[ENTRY_PUBKEY_URL])); 
+  url = gtk_entry_get_text (GTK_ENTRY (card->entries[ENTRY_PUBKEY_URL]));
   if (!url || !*url)
     return;
 
@@ -1283,7 +1295,7 @@ pubkey_url_menu_fetch_key (GtkMenuItem *menuitem, void *opaque)
   err = gpgme_op_import (ctx, urllist);
   if (err)
     {
-      char *message = g_strdup_printf 
+      char *message = g_strdup_printf
         (_("Error fetching the key.\n"
            "(%s <%s>)"), gpg_strerror (err), gpg_strsource (err));
       gpa_cm_object_alert_dialog (GPA_CM_OBJECT (card), message);
@@ -1296,14 +1308,14 @@ pubkey_url_menu_fetch_key (GtkMenuItem *menuitem, void *opaque)
       impres = gpgme_op_import_result (ctx);
       if (impres)
         {
-          char *message = g_strdup_printf 
+          char *message = g_strdup_printf
             (_("Keys found: %d, imported: %d, unchanged: %d"),
              impres->considered, impres->imported, impres->unchanged);
           gpa_cm_object_update_status (GPA_CM_OBJECT(card), message);
           xfree (message);
         }
     }
-  
+
   gpgme_release (ctx);
   gpgme_data_release (urllist);
 }
@@ -1341,9 +1353,9 @@ add_table_row (GtkWidget *table, int *rowidx,
   label = gtk_label_new (labelstr);
   gtk_label_set_width_chars  (GTK_LABEL (label), 22);
   gtk_misc_set_alignment (GTK_MISC (label), 0, 0);
-  gtk_table_attach (GTK_TABLE (table), label, 0, 1,	       
-                    *rowidx, *rowidx + 1, GTK_FILL, GTK_FILL, 0, 0); 
-  
+  gtk_table_attach (GTK_TABLE (table), label, 0, 1,
+                    *rowidx, *rowidx + 1, GTK_FILL, GTK_FILL, 0, 0);
+
   if (is_label)
     gtk_misc_set_alignment (GTK_MISC (widget), 0, 0.5);
 
@@ -1406,7 +1418,7 @@ construct_data_widget (GpaCMOpenpgp *card)
   rowidx = 0;
 
   card->entries[ENTRY_SERIALNO] = gtk_label_new (NULL);
-  add_table_row (general_table, &rowidx, _("Serial number:"), 
+  add_table_row (general_table, &rowidx, _("Serial number:"),
                  card->entries[ENTRY_SERIALNO], NULL, 0, 1);
 
   card->entries[ENTRY_VERSION] = gtk_label_new (NULL);
@@ -1441,7 +1453,7 @@ construct_data_widget (GpaCMOpenpgp *card)
 
   card->entries[ENTRY_FIRST_NAME] = gtk_entry_new ();
   gtk_entry_set_max_length (GTK_ENTRY (card->entries[ENTRY_FIRST_NAME]), 35);
-  add_table_row (personal_table, &rowidx, 
+  add_table_row (personal_table, &rowidx,
                  _("First name:"), card->entries[ENTRY_FIRST_NAME], NULL, 0, 0);
 
   card->entries[ENTRY_LAST_NAME] = gtk_entry_new ();
@@ -1514,32 +1526,32 @@ construct_data_widget (GpaCMOpenpgp *card)
 
   pin_table = gtk_table_new (4, 3, FALSE);
   gtk_container_set_border_width (GTK_CONTAINER (pin_table), 10);
-  
+
   rowidx = 0;
 
   card->entries[ENTRY_SIG_FORCE_PIN] = gtk_check_button_new ();
-  add_table_row (pin_table, &rowidx, 
+  add_table_row (pin_table, &rowidx,
                  _("Force signature PIN:"),
                  card->entries[ENTRY_SIG_FORCE_PIN], NULL, 0, 1);
   card->entries[ENTRY_PIN_RETRYCOUNTER] = gtk_label_new (NULL);
   button = gtk_button_new ();
-  add_table_row (pin_table, &rowidx, _("PIN retry counter:"), 
+  add_table_row (pin_table, &rowidx, _("PIN retry counter:"),
                  card->entries[ENTRY_PIN_RETRYCOUNTER], button, 1, 1);
-  card->change_pin_btn[0] = button; 
+  card->change_pin_btn[0] = button;
 
   card->entries[ENTRY_PUK_RETRYCOUNTER] = gtk_label_new (NULL);
   button = gtk_button_new ();
-  card->puk_label = 
-    add_table_row (pin_table, &rowidx, 
-                   "", /* The label depends on the card version.  */ 
+  card->puk_label =
+    add_table_row (pin_table, &rowidx,
+                   "", /* The label depends on the card version.  */
                    card->entries[ENTRY_PUK_RETRYCOUNTER], button, 1, 1);
-  card->change_pin_btn[1] = button; 
+  card->change_pin_btn[1] = button;
 
   card->entries[ENTRY_ADMIN_PIN_RETRYCOUNTER] = gtk_label_new (NULL);
   button = gtk_button_new ();
   add_table_row (pin_table, &rowidx, _("Admin-PIN retry counter:"),
                  card->entries[ENTRY_ADMIN_PIN_RETRYCOUNTER], button, 1, 1);
-  card->change_pin_btn[2] = button; 
+  card->change_pin_btn[2] = button;
 
   gtk_container_add (GTK_CONTAINER (pin_frame), pin_table);
 
@@ -1593,8 +1605,8 @@ construct_data_widget (GpaCMOpenpgp *card)
   for (idx=0; idx < 3; idx++)
     g_signal_connect (G_OBJECT (card->change_pin_btn[idx]), "clicked",
                       G_CALLBACK (change_pin_clicked_cb), card);
-  
-  g_signal_connect (G_OBJECT (card->entries[ENTRY_PUBKEY_URL]), 
+
+  g_signal_connect (G_OBJECT (card->entries[ENTRY_PUBKEY_URL]),
                     "populate-popup",
                     G_CALLBACK (pubkey_url_populate_popup_cb), card);
 
@@ -1603,7 +1615,7 @@ construct_data_widget (GpaCMOpenpgp *card)
 
 
 
-/************************************************************ 
+/************************************************************
  ******************   Object Management  ********************
  ************************************************************/
 
@@ -1613,7 +1625,7 @@ gpa_cm_openpgp_class_init (void *class_ptr, void *class_data)
   GpaCMOpenpgpClass *klass = class_ptr;
 
   parent_class = g_type_class_peek_parent (klass);
-  
+
   G_OBJECT_CLASS (klass)->finalize = gpa_cm_openpgp_finalize;
 }
 
@@ -1630,7 +1642,7 @@ gpa_cm_openpgp_init (GTypeInstance *instance, void *class_ptr)
 
 static void
 gpa_cm_openpgp_finalize (GObject *object)
-{  
+{
   GpaCMOpenpgp *card = GPA_CM_OPENPGP (object);
 
   xfree (card->key_attributes);
@@ -1645,7 +1657,7 @@ GType
 gpa_cm_openpgp_get_type (void)
 {
   static GType this_type = 0;
-  
+
   if (!this_type)
     {
       static const GTypeInfo this_info =
@@ -1660,23 +1672,23 @@ gpa_cm_openpgp_get_type (void)
 	  0,    /* n_preallocs */
 	  gpa_cm_openpgp_init
 	};
-      
+
       this_type = g_type_register_static (GPA_CM_OBJECT_TYPE,
                                           "GpaCMOpenpgp",
                                           &this_info, 0);
     }
-  
+
   return this_type;
 }
 
 
-/************************************************************ 
+/************************************************************
  **********************  Public API  ************************
  ************************************************************/
 GtkWidget *
 gpa_cm_openpgp_new ()
 {
-  return GTK_WIDGET (g_object_new (GPA_CM_OPENPGP_TYPE, NULL));  
+  return GTK_WIDGET (g_object_new (GPA_CM_OPENPGP_TYPE, NULL));
 }
 
 
